#include <iostream>
#include "circle10.h"
#include <cassert>

namespace {
  const float pi = 3.14159;
} // namespace


// class Circle
Circle::Circle( const Point& p, const float& r) : P(p), rad(r) 
{
  quadric = gluNewQuadric();
  assert( quadric);
  gluQuadricDrawStyle(quadric, (GLenum) GLU_FILL );
}

float Circle::radius() const
{ return rad; }

float Circle::area() const
{ return pi * rad * rad; }

float Circle::circumference() const
{ return 2 * pi * rad; }

Point Circle::center() const
{ return P; }

void Circle::draw() const
{
  glPushMatrix();
  glTranslatef( P.x(), P.y(), 0.0);
  gluDisk( quadric, 0.0, rad, 40, 1);
  glPopMatrix();
}

// class ColoredCircle
ColoredCircle::ColoredCircle( const Point& p, const float& r) 
 : Circle( p, r), col( Color( 1.0, 1.0, 1.0)) 
{}

ColoredCircle::ColoredCircle( const Point& p, const float& r, const Color& c) 
 : Circle( p, r), col(c) 
{}

void ColoredCircle::draw() const
{
  glColor3f( col.red(), col.green(), col.blue());
  glPushMatrix();
  glTranslatef( P.x(), P.y(), 0.0);
  gluDisk( quadric, 0.0, rad, 40, 1);
  glPopMatrix();
}
