#include <iostream>
#include "circle11.h"
#include <cassert>

namespace {
  const float pi = 3.14159;
} // namespace


// class Circle
void
Circle::new_quadric()
{
  quadric = gluNewQuadric();
  assert( quadric);
  gluQuadricDrawStyle(quadric, (GLenum) GLU_FILL ); 
}

void
Circle::free_quadric()
{
  gluDeleteQuadric( quadric);
  quadric = NULL;
}

Circle::Circle( const Point& p, const float& r) : P(p), rad(r) 
{ new_quadric(); }

Circle::Circle(const Circle& c) : P(c.P), rad(c.rad)
{ new_quadric(); }

Circle&
Circle::operator=(const Circle& c)
{
  if ( &c == this) return *this;
  P = c.P;
  rad = c.rad;
  free_quadric();
  new_quadric();
}

Circle::~Circle()
{ free_quadric(); }

float Circle::radius() const
{ return rad; }

float Circle::area() const
{ return pi * rad * rad; }

float Circle::circumference() const
{ return 2 * pi * rad; }

Point Circle::center() const
{ return P; }

void Circle::draw() const
{
  glPushMatrix();
  glTranslatef( P.x(), P.y(), 0.0);
  assert( quadric);
  gluDisk( quadric, 0.0, rad, 40, 1);
  glPopMatrix();
}

// class ColoredCircle
ColoredCircle::ColoredCircle( const Point& p, const float& r) 
 : Circle( p, r), col( Color( 1.0, 1.0, 1.0)) 
{}

ColoredCircle::ColoredCircle( const Point& p, const float& r, const Color& c) 
 : Circle( p, r), col(c) 
{}

ColoredCircle::ColoredCircle( const ColoredCircle& c) 
 : Circle(c), col( c.col) 
{}

ColoredCircle&
ColoredCircle::operator=( const ColoredCircle& c)
{ 
  col = c.col; 
  return *this;
}

ColoredCircle::~ColoredCircle() 
{}

void ColoredCircle::draw() const
{
  glColor3f( col.red(), col.green(), col.blue());
  glPushMatrix();
  glTranslatef( P.x(), P.y(), 0.0);
  assert( quadric);
  gluDisk( quadric, 0.0, rad, 40, 1);
  glPopMatrix();
}
